v0.2.1 (2021-03-31)
-------------------
- BCC headers are now removed from e-mails before submitting to Mailgun, which
  does not remove BCC's itself

v0.2.0 (2021-03-14)
-------------------
- Added logging

v0.1.0 (2021-03-08)
-------------------
Initial release
